==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/applications/wizard/WizardController.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

/** CONTROLLER of the model*/

// Import .h file
#include "WizardController.h"

//Imports from Qt
#include <QFinalState>

// States
#include "WizardState.h"

// Include Widgets
#include "DorothyMainWindow.h"

#include "WelcomeWidget.h"
#include "CepCreateOrModifyWidget.h"
#include "CepCreationDirectoryWidget.h"
#include "CepCreationDirectoryState.h"

#include "CepDescriptionWidget.h"
#include "CepDescriptionState.h"

#include "CepContactWidget.h"
#include "CepContactState.h"

#include "CepCreateRecapWidget.h"
#include "CepCreateRecapState.h"

#include "GeneratingCEPWidget.h"
#include "GeneratingCEPState.h"

#include "ActionExtensionCreationState.h"
#include "ComponentExtensionCreationState.h"
#include "LibraryCreationState.h"


#include <Cep.hxx>
#include <Contact.hxx>

#include <iostream>

/**  Constructor: creation of all the interfaces and the connect */
WizardController::WizardController(void)
{
    this->mainWindow = new DorothyMainWindow();
    devDirectoryName = "Hello World";
    cepcoreschema::Contact c;
    this->domCep = new cepcoreschema::Cep("CEP not yet defined...", c, "to be defined");

    // Welcome
    WelcomeWidget * welcomeWidget = new WelcomeWidget(NULL);
    WizardState * welcomeState = new WizardState("Welcome",  welcomeWidget, mainWindow);
    // Create a new CEP or work on an existing one ?
    CepCreateOrModifyWidget * cepCreateOrModifyWidget = new CepCreateOrModifyWidget(NULL);
    WizardState * cepCreateOrModifyState = new WizardState("Create / Modify a CEP ?", cepCreateOrModifyWidget, mainWindow);
    // Create the state where to enter the directory for a cep creation
    CepCreationDirectoryWidget * cepCreationDirectoryWidget = new CepCreationDirectoryWidget(NULL);
    CepCreationDirectoryState * cepCreationDirectoryState = new CepCreationDirectoryState("Creation Directory", cepCreationDirectoryWidget, mainWindow, &devDirectoryName);
    // CEP general description
    CepDescriptionWidget * cepDescriptionWidget = new CepDescriptionWidget(NULL);
    CepDescriptionState * cepDescriptionState = new CepDescriptionState("CEP Description", cepDescriptionWidget, mainWindow, domCep);
    // CEP contact and licence
    CepContactWidget * cepContactWidget = new CepContactWidget(NULL);
    CepContactState * cepContactState = new CepContactState("CEP contact and licence", cepContactWidget, mainWindow, domCep);
    // CEP Recap
    CepCreateRecapWidget * cepCreateRecapWidget = new CepCreateRecapWidget(NULL);
    CepCreateRecapState * cepCreateRecapState = new CepCreateRecapState("CEP Recap", cepCreateRecapWidget, mainWindow, domCep);

    // --------------------------     Action extensions
    ActionExtensionCreationState * actionExtensionCreationState = new ActionExtensionCreationState("Action Extension State", mainWindow, domCep);

    // --------------------------     Component extensions
    ComponentExtensionCreationState * componentExtensionCreationState = new ComponentExtensionCreationState("Component Extension State", mainWindow, domCep);
    // --------------------------     Libraries
    QMap<QString, QStringList> * libraryCopyFilesMap = new QMap<QString, QStringList>();
    LibraryCreationState * libraryCreationState = new LibraryCreationState("Library Creation State", mainWindow, domCep, libraryCopyFilesMap);

    GeneratingCEPWidget * generatingCEPWidget = new GeneratingCEPWidget(NULL);
    GeneratingCEPState * generatingCEPState = new GeneratingCEPState("Generating CEP...", generatingCEPWidget, mainWindow, domCep, &devDirectoryName, libraryCopyFilesMap);


    // Quit state...
    QFinalState * finalState = new QFinalState();


    machine.addState(welcomeState);
    machine.addState(cepCreateOrModifyState);
    machine.addState(cepCreationDirectoryState);
    machine.addState(cepDescriptionState);
    machine.addState(cepContactState);
    machine.addState(cepCreateRecapState);

    machine.addState(actionExtensionCreationState);
    machine.addState(componentExtensionCreationState);
    machine.addState(libraryCreationState);

    machine.addState(generatingCEPState);

    machine.addState(finalState);

    // Adding transitions...
    machine.setInitialState(welcomeState);

    welcomeState->addTransition(welcomeWidget, SIGNAL(next()), cepCreateOrModifyState);
    
    cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(backCep()), welcomeState);
    cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(newCep()), cepCreationDirectoryState);
    
    
    cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(previous()), cepCreateOrModifyState);
    cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(next()), cepDescriptionState);
    
    cepDescriptionState->addTransition(cepDescriptionWidget, SIGNAL(previous()), cepCreationDirectoryState);
    cepDescriptionState->addTransition(cepDescriptionWidget, SIGNAL(next()), cepContactState);
    
    cepContactState->addTransition(cepContactWidget, SIGNAL(previous()), cepDescriptionState);
    cepContactState->addTransition(cepContactWidget, SIGNAL(next()), cepCreateRecapState);

    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(addActionExtension()), actionExtensionCreationState);
    actionExtensionCreationState->addTransition(actionExtensionCreationState, SIGNAL(next()), cepCreateRecapState);

    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(addComponentExtension()), componentExtensionCreationState);
    componentExtensionCreationState->addTransition(componentExtensionCreationState, SIGNAL(next()), cepCreateRecapState);
    
    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(addLibrary()), libraryCreationState);
    libraryCreationState->addTransition(libraryCreationState, SIGNAL(next()), cepCreateRecapState);
                                       
    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(next()), generatingCEPState);
    generatingCEPState->addTransition(generatingCEPWidget, SIGNAL(next()), finalState);

    QObject::connect(&machine, SIGNAL(finished()), QApplication::instance(), SLOT(quit()));

}


/**  Destructor of the Controller */
WizardController::~WizardController(void) {}

/** Method to start */
void WizardController::launch()
{
    machine.start();
    mainWindow->show();
}

==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/sdk/applications/wizard/WizardController.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

/** CONTROLLER of the model*/

// Import .h file
#include "WizardController.h"

//Imports from Qt
#include <QFinalState>

// States
#include "WizardState.h"

// Include Widgets
#include "DorothyMainWindow.h"

#include "WelcomeWidget.h"
#include "CepCreateOrModifyWidget.h"
#include "CepCreationDirectoryWidget.h"
#include "CepCreationDirectoryState.h"

#include "CepDescriptionWidget.h"
#include "CepDescriptionState.h"

#include "CepContactWidget.h"
#include "CepContactState.h"

#include "CepCreateRecapWidget.h"
#include "CepCreateRecapState.h"

#include "GeneratingCEPWidget.h"
#include "GeneratingCEPState.h"

#include "ActionExtensionCreationState.h"
#include "ComponentExtensionCreationState.h"
#include "LibraryCreationState.h"


#include <Cep.hxx>
#include <Contact.hxx>

#include <iostream>

/**  Constructor: creation of all the interfaces and the connect */
WizardController::WizardController(void) {
    this->mainWindow = new DorothyMainWindow();
    devDirectoryName = "Hello World";
    cepcoreschema::Contact c;
    this->domCep = new cepcoreschema::Cep("CEP not yet defined...", c, "to be defined");

    // Welcome
    WelcomeWidget * welcomeWidget = new WelcomeWidget(NULL);
    WizardState * welcomeState = new WizardState("Welcome",  welcomeWidget, mainWindow);
    // Create a new CEP or work on an existing one ?
    CepCreateOrModifyWidget * cepCreateOrModifyWidget = new CepCreateOrModifyWidget(NULL);
    WizardState * cepCreateOrModifyState = new WizardState("Create / Modify a CEP ?", cepCreateOrModifyWidget, mainWindow);
    // Create the state where to enter the directory for a cep creation
    CepCreationDirectoryWidget * cepCreationDirectoryWidget = new CepCreationDirectoryWidget(NULL);
    CepCreationDirectoryState * cepCreationDirectoryState = new CepCreationDirectoryState("Creation Directory", cepCreationDirectoryWidget, mainWindow, &devDirectoryName);
    // CEP general description
    CepDescriptionWidget * cepDescriptionWidget = new CepDescriptionWidget(NULL);
    CepDescriptionState * cepDescriptionState = new CepDescriptionState("CEP Description", cepDescriptionWidget, mainWindow, domCep);
    // CEP contact and licence
    CepContactWidget * cepContactWidget = new CepContactWidget(NULL);
    CepContactState * cepContactState = new CepContactState("CEP contact and licence", cepContactWidget, mainWindow, domCep);
    // CEP Recap
    CepCreateRecapWidget * cepCreateRecapWidget = new CepCreateRecapWidget(NULL);
    CepCreateRecapState * cepCreateRecapState = new CepCreateRecapState("CEP Recap", cepCreateRecapWidget, mainWindow, domCep);

    // --------------------------     Action extensions
    ActionExtensionCreationState * actionExtensionCreationState = new ActionExtensionCreationState("Action Extension State", mainWindow, domCep);

    // --------------------------     Component extensions
    ComponentExtensionCreationState * componentExtensionCreationState = new ComponentExtensionCreationState("Component Extension State", mainWindow, domCep);
    // --------------------------     Libraries
    QMap<QString, QStringList> * libraryCopyFilesMap = new QMap<QString, QStringList>();
    LibraryCreationState * libraryCreationState = new LibraryCreationState("Library Creation State", mainWindow, domCep, libraryCopyFilesMap);

    GeneratingCEPWidget * generatingCEPWidget = new GeneratingCEPWidget(NULL);
    GeneratingCEPState * generatingCEPState = new GeneratingCEPState("Generating CEP...", generatingCEPWidget, mainWindow, domCep, &devDirectoryName, libraryCopyFilesMap);


    // Quit state...
    QFinalState * finalState = new QFinalState();


    machine.addState(welcomeState);
    machine.addState(cepCreateOrModifyState);
    machine.addState(cepCreationDirectoryState);
    machine.addState(cepDescriptionState);
    machine.addState(cepContactState);
    machine.addState(cepCreateRecapState);

    machine.addState(actionExtensionCreationState);
    machine.addState(componentExtensionCreationState);
    machine.addState(libraryCreationState);

    machine.addState(generatingCEPState);

    machine.addState(finalState);

    // Adding transitions...
    machine.setInitialState(welcomeState);

    welcomeState->addTransition(welcomeWidget, SIGNAL(next()), cepCreateOrModifyState);

    cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(backCep()), welcomeState);
    cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(newCep()), cepCreationDirectoryState);


    cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(previous()), cepCreateOrModifyState);
    cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(next()), cepDescriptionState);

    cepDescriptionState->addTransition(cepDescriptionWidget, SIGNAL(previous()), cepCreationDirectoryState);
    cepDescriptionState->addTransition(cepDescriptionWidget, SIGNAL(next()), cepContactState);

    cepContactState->addTransition(cepContactWidget, SIGNAL(previous()), cepDescriptionState);
    cepContactState->addTransition(cepContactWidget, SIGNAL(next()), cepCreateRecapState);

    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(addActionExtension()), actionExtensionCreationState);
    actionExtensionCreationState->addTransition(actionExtensionCreationState, SIGNAL(next()), cepCreateRecapState);

    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(addComponentExtension()), componentExtensionCreationState);
    componentExtensionCreationState->addTransition(componentExtensionCreationState, SIGNAL(next()), cepCreateRecapState);

    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(addLibrary()), libraryCreationState);
    libraryCreationState->addTransition(libraryCreationState, SIGNAL(next()), cepCreateRecapState);

    cepCreateRecapState->addTransition(cepCreateRecapWidget, SIGNAL(next()), generatingCEPState);
    generatingCEPState->addTransition(generatingCEPWidget, SIGNAL(next()), finalState);

    QObject::connect(&machine, SIGNAL(finished()), QApplication::instance(), SLOT(quit()));

}


/**  Destructor of the Controller */
WizardController::~WizardController(void) {}

/** Method to start */
void WizardController::launch() {
    machine.start();
    mainWindow->show();
}
